@@ -13,7 +13,7 @@ from .styles import cms as style
 
 # import mplhep._deprecate as deprecate
 
-__all__ = ("style", "lumitext")
+__all__ = ("lumitext", "style")
 
 
 @docstring.copy(label_base.exp_text)
