@@ -6,7 +6,9 @@ import matplotlib as mpl
 from cycler import cycler
 
 # Color wheel from https://arxiv.org/pdf/2107.02270 Table 1, 10 color palette
-color_sequence = [
+# This is the color wheel recommended for plots that require a large number
+# of colors that would not be satisfied by the below palette
+color_sequence1 = [
     "#3f90da",
     "#ffa90e",
     "#bd1f01",
@@ -19,6 +21,20 @@ color_sequence = [
     "#92dadd",
 ]
 
+# Color wheel based on internal discussions of optimal
+# colors for visibility, accounting for color vision deficiency
+# The recommendation for signal is the first color (Vermilion)
+# For large signals, ROOT.kWhite / '#ffffff' is also an option
+color_sequence2 = [
+    "#d55e00",
+    "#56b4e9",
+    "#e69f00",
+    "#f0e442",
+    "#009e73",
+    "#cc79a7",
+    "#0072b2",
+]
+
 _base = {
     # fonts and text
     # initially from https://github.com/kratsg/ATLASstylempl
@@ -49,7 +65,6 @@ _base = {
     "figure.subplot.left": 0.16,
     "figure.subplot.right": 0.95,
     # axes
-    "axes.prop_cycle": cycler("color", color_sequence),
     "axes.titlesize": "xx-large",
     "axes.labelsize": "x-large",
     "axes.linewidth": 1,
@@ -106,8 +121,22 @@ _base = {
     "savefig.transparent": False,
 }
 
-ATLAS: dict[str, Any] = {
+ATLAS1: dict[str, Any] = {
     **_base,
+    "axes.prop_cycle": cycler("color", color_sequence1),
+    "mathtext.fontset": "custom",
+    "mathtext.rm": "TeX Gyre Heros",
+    "mathtext.bf": "TeX Gyre Heros:bold",
+    "mathtext.sf": "TeX Gyre Heros",
+    "mathtext.it": "TeX Gyre Heros:italic",
+    "mathtext.tt": "TeX Gyre Heros",
+    "mathtext.cal": "TeX Gyre Heros",
+    "mathtext.default": "it",
+}
+
+ATLAS2: dict[str, Any] = {
+    **_base,
+    "axes.prop_cycle": cycler("color", color_sequence2),
     "mathtext.fontset": "custom",
     "mathtext.rm": "TeX Gyre Heros",
     "mathtext.bf": "TeX Gyre Heros:bold",
@@ -121,12 +150,13 @@ ATLAS: dict[str, Any] = {
 # use dejavusans (default math fontset)
 ATLASAlt: dict[str, Any] = {
     **_base,
+    "axes.prop_cycle": cycler("color", color_sequence1),
     "mathtext.default": "it",
 }
 
 # use LaTeX
 ATLASTex: dict[str, Any] = {
-    **_base,
+    **ATLAS2,
     "text.usetex": True,
     "text.latex.preamble": "\n".join(
         [
@@ -144,6 +174,10 @@ ATLASTex: dict[str, Any] = {
 }
 
 # Filter extra (labellocation) items if needed
-ATLAS = {k: v for k, v in ATLAS.items() if k in mpl.rcParams}
+ATLAS1 = {k: v for k, v in ATLAS1.items() if k in mpl.rcParams}
+ATLAS2 = {k: v for k, v in ATLAS2.items() if k in mpl.rcParams}
 ATLASAlt = {k: v for k, v in ATLASAlt.items() if k in mpl.rcParams}
 ATLASTex = {k: v for k, v in ATLASTex.items() if k in mpl.rcParams}
+
+# Alias 'ATLAS' to the one that most folks should use
+ATLAS = ATLAS2.copy()
